==> bglibs-1.017.tbz: include/bglibs/sysdeps.h <==
#ifndef SYS_DEPS__H__
#define SYS_DEPS__H__

#include <sys/types.h>
typedef unsigned char uint8;
typedef unsigned short uint16;
/* sysdep: -ulong32 */
typedef unsigned int uint32;
/* sysdep: +ulong64 */
#define HAS_ULONG64 1
typedef unsigned long uint64;
/* sysdep: endian=msb */
#undef ENDIAN_LSB
#define ENDIAN_MSB 1
#ifndef DIRENTRY_H
#define DIRENTRY_H

/* sysdep: -direct */
/* sysdep: +dirent */
#include <dirent.h>
#define direntry struct dirent

#endif
/* sysdep: +hasipv6 */
#define HASIPV6 1
#ifndef FORK_H
#define FORK_H

/* sysdep: +vfork */
extern pid_t fork();
extern pid_t vfork();

#endif
/* sysdep: -getpeereid */
extern int getpeereid(int s, uid_t* u, gid_t* g);
/* sysdep: +hasflock */
#define HASFLOCK 1

/* sysdep: -struct ucred */
/* sysdep: -linux_sendfile */
/* sysdep: +sigaction */
#define HASSIGACTION 1
/* sysdep: +sigprocmask */
#define HASSIGPROCMASK 1
/* sysdep: -hasspnam */

/* sysdep: -hasuserpw */

/* sysdep: +waitpid */
#define HASWAITPID 1
/* sysdep: +haszlib */
#define HASZLIB 1
#ifndef IOPOLL_H
#define IOPOLL_H

/* sysdep: +poll */
#define IOPOLL_POLL

#include <poll.h>

typedef struct pollfd iopoll_fd;
#define IOPOLL_READ POLLIN
#define IOPOLL_WRITE POLLOUT
#define iopoll poll

extern int iopoll_restart(iopoll_fd* fds, unsigned nfds, unsigned long timeout);

#endif
#ifndef SELECT_H
#define SELECT_H

/* sysdep: +sysselect */

#include <sys/time.h>
#include <sys/select.h>
extern int select();

#endif
/* sysdep: +setenv */
#define HASSETENV 1
#include <stdlib.h>
/* sysdep: +unsetenv */
#define HASUNSETENV 1
/* sysdep: -unaligned */
#undef HAS_UNALIGNED_ACCESSES

#endif

==> bglibs-1.019.tbz: include/bglibs/sysdeps.h <==
#ifndef SYS_DEPS__H__
#define SYS_DEPS__H__

#include <sys/types.h>
typedef unsigned char uint8;
typedef unsigned short uint16;
/* sysdep: -ulong32 */
typedef unsigned int uint32;
/* sysdep: +ulong64 */
#define HAS_ULONG64 1
typedef unsigned long uint64;
/* sysdep: endian=lsb */
#define ENDIAN_LSB 1
#undef ENDIAN_MSB
#ifndef DIRENTRY_H
#define DIRENTRY_H

/* sysdep: -direct */
/* sysdep: +dirent */
#include <dirent.h>
#define direntry struct dirent

#endif
/* sysdep: +hasipv6 */
#define HASIPV6 1
#ifndef FORK_H
#define FORK_H

/* sysdep: +vfork */
extern pid_t fork();
extern pid_t vfork();

#endif
/* sysdep: -getpeereid */
extern int getpeereid(int s, uid_t* u, gid_t* g);
/* sysdep: +hasflock */
#define HASFLOCK 1

/* sysdep: -struct ucred */
/* sysdep: -linux_sendfile */
/* sysdep: +sigaction */
#define HASSIGACTION 1
/* sysdep: +sigprocmask */
#define HASSIGPROCMASK 1
/* sysdep: -hasspnam */

/* sysdep: -hasuserpw */

/* sysdep: +waitpid */
#define HASWAITPID 1
/* sysdep: +haszlib */
#define HASZLIB 1
#ifndef IOPOLL_H
#define IOPOLL_H

/* sysdep: +poll */
#define IOPOLL_POLL

#include <poll.h>

typedef struct pollfd iopoll_fd;
#define IOPOLL_READ POLLIN
#define IOPOLL_WRITE POLLOUT
#define iopoll poll

extern int iopoll_restart(iopoll_fd* fds, unsigned nfds, unsigned long timeout);

#endif
#ifndef SELECT_H
#define SELECT_H

/* sysdep: +sysselect */

#include <sys/time.h>
#include <sys/select.h>
extern int select();

#endif
/* sysdep: +setenv */
#define HASSETENV 1
#include <stdlib.h>
/* sysdep: +unsetenv */
#define HASUNSETENV 1
/* sysdep: +unaligned */
#define HAS_UNALIGNED_ACCESSES 1
/* sysdep: +hasmkfifo */
#define HASMKFIFO 1
/* sysdep: -hasnamedpipebug */

/* sysdep: +hasinline */
#define HASINLINE

#endif
